'use strict';

const AWS = require('aws-sdk');
const dynamoDb = new AWS.DynamoDB.DocumentClient({
  region: process.env.AWS_DYNAMODB_REGION || 'us-east-1'
});

function scan(params) {

  return new Promise((resolve, reject) => dynamoDb.scan(params).promise().then(data => resolve(data.Items)).catch(err => reject(err)));
}

function get(params) {

  return new Promise((resolve, reject) => dynamoDb.get(params).promise().then(data => resolve(data.Item)).catch(err => reject(err)));
}

function createItem(params) {

  return new Promise((resolve, reject) => dynamoDb.put(params).promise().then(() => resolve(params.Item)).catch(err => reject(err)));
}

function updateItem(params) {

  return new Promise((resolve, reject) => dynamoDb.update(params).promise().then(data => resolve(data.Attributes)).catch(err => reject(err)));
}

function deleteItem(params, args) {

  return new Promise((resolve, reject) => dynamoDb.delete(params).promise().then(() => resolve(args)).catch(err => reject(err)));
}

function query(params) {

  return new Promise((resolve, reject) => dynamoDb.query(params).promise().then(data => resolve(data.Items)).catch(err => reject(err)));
}

module.exports = {
  deleteItem,
  updateItem,
  createItem,
  get,
  scan,
  query
};